import { Test as Test$1 } from 'a';
import Test$2 from 'b';

const Test = () => {
  console.log(Test$1);
};

const Test1 = () => {
  console.log(Test$2);
};

export { Test, Test1 };
